@@ -15,6 +15,9 @@
 # limitations under the License.
 
 
+import collections
+
+
 class lazy_import:  # pylint: disable=invalid-name, too-few-public-methods
     """
     Lazily import the given module.
@@ -32,3 +35,6 @@ class lazy_import:  # pylint: disable=invalid-name, too-few-public-methods
         if self._module is None:
             self._module = __import__(self.module)
         return getattr(self._module, name)
+
+
+Quantity = collections.namedtuple('Quantity', ['value', 'unit'])
